@@ -2,20 +2,18 @@
 # Copyright 2024 Mike Schultz
 
 # djk/pipes/head.py
+from pjk.base import Pipe, ParsedToken, Usage
 
-from typing import Optional
-from pjk.base import Pipe, ParsedToken, Usage, DeepCopyPipe
-
-class HeadPipe(DeepCopyPipe):
+class HeadPipe(Pipe):
     @classmethod
     def usage(cls):
         usage = Usage(
             name='head',
-            desc='take first records of input (when single-threaded)',
+            desc='take first records of input',
             component_class=cls
         )
-        usage.def_arg(name='limit', usage='number of records', is_num=True)
         usage.def_example(expr_tokens=['[{id:1}, {id:2}]', 'head:1'], expect="{id:1}")
+        usage.def_arg(name='limit', usage='number of records', is_num=True)
         return usage
 
     def __init__(self, ptok: ParsedToken, usage: Usage):
